Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(771)

Unified Diff: chrome/browser/download/all_download_item_notifier.h

Issue 10974009: Rename HyperbolicDownloadItemNotifer -> AllDownloadItemNotifier (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/download/all_download_item_notifier.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/download/all_download_item_notifier.h
diff --git a/chrome/browser/download/hyperbolic_download_item_notifier.h b/chrome/browser/download/all_download_item_notifier.h
similarity index 73%
rename from chrome/browser/download/hyperbolic_download_item_notifier.h
rename to chrome/browser/download/all_download_item_notifier.h
index e6c0895c9348ba05385b6fbce6a25b15f05d4b34..73c661c93a33aecee109dae09fe308e23db3930b 100644
--- a/chrome/browser/download/hyperbolic_download_item_notifier.h
+++ b/chrome/browser/download/all_download_item_notifier.h
@@ -2,27 +2,27 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_DOWNLOAD_HYPERBOLIC_DOWNLOAD_ITEM_NOTIFIER_H_
-#define CHROME_BROWSER_DOWNLOAD_HYPERBOLIC_DOWNLOAD_ITEM_NOTIFIER_H_
+#ifndef CHROME_BROWSER_DOWNLOAD_ALL_DOWNLOAD_ITEM_NOTIFIER_H_
+#define CHROME_BROWSER_DOWNLOAD_ALL_DOWNLOAD_ITEM_NOTIFIER_H_
#include <set>
#include "content/public/browser/download_manager.h"
#include "content/public/browser/download_item.h"
// HyperbolicDownloadItemNotifier observes ALL the DownloadItems on a given
// DownloadManager.
// Clients should use GetManager() instead of storing their own pointer to the
// manager so that they can be sensitive to managers that have gone down.
// Example Usage:
-// class AndAHalf : public HyperbolicDownloadItemNotifier::Observer {
+// class DownloadSystemConsumer : public AllDownloadItemNotifier::Observer {
// public:
-// AndAHalf(content::DownloadManager* original_manager,
+// DownloadSystemConsumer(content::DownloadManager* original_manager,
// content::DownloadManager* incognito_manager)
-// : ALLOW_THIS_IN_INITIALIZATION_LIST(original_hyperbole_(
+// : ALLOW_THIS_IN_INITIALIZATION_LIST(original_notifier_(
// original_manager, this)),
-// ALLOW_THIS_IN_INITIALIZATION_LIST(incognito_hyperbole_(
+// ALLOW_THIS_IN_INITIALIZATION_LIST(incognito_notifier_(
// incognito_manager, this)) {
// }
//
@@ -30,11 +30,11 @@
// content::DownloadManager* manager, content::DownloadItem* item) { ... }
//
// private:
-// HyperbolicDownloadItemNotifier original_hyperbole_;
-// HyperbolicDownloadItemNotifier incognito_hyperbole_;
+// AllDownloadItemNotifier original_notifier_;
+// AllDownloadItemNotifier incognito_notifier_;
// };
-class HyperbolicDownloadItemNotifier
+class AllDownloadItemNotifier
: public content::DownloadManager::Observer,
public content::DownloadItem::Observer {
public:
@@ -59,10 +59,10 @@ class HyperbolicDownloadItemNotifier
DISALLOW_COPY_AND_ASSIGN(Observer);
};
- HyperbolicDownloadItemNotifier(content::DownloadManager* manager,
+ AllDownloadItemNotifier(content::DownloadManager* manager,
Observer* observer);
- virtual ~HyperbolicDownloadItemNotifier();
+ virtual ~AllDownloadItemNotifier();
// Returns NULL if the manager has gone down.
content::DownloadManager* GetManager() const { return manager_; }
@@ -80,10 +80,10 @@ class HyperbolicDownloadItemNotifier
virtual void OnDownloadDestroyed(content::DownloadItem* item) OVERRIDE;
content::DownloadManager* manager_;
- HyperbolicDownloadItemNotifier::Observer* observer_;
+ AllDownloadItemNotifier::Observer* observer_;
std::set<content::DownloadItem*> observing_;
- DISALLOW_COPY_AND_ASSIGN(HyperbolicDownloadItemNotifier);
+ DISALLOW_COPY_AND_ASSIGN(AllDownloadItemNotifier);
};
-#endif // CHROME_BROWSER_DOWNLOAD_HYPERBOLIC_DOWNLOAD_ITEM_NOTIFIER_H_
+#endif // CHROME_BROWSER_DOWNLOAD_ALL_DOWNLOAD_ITEM_NOTIFIER_H_
« no previous file with comments | « no previous file | chrome/browser/download/all_download_item_notifier.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,27 +2,27 @@
#include "content/public/browser/download_manager.h"
#include "content/public/browser/download_item.h"
-// HyperbolicDownloadItemNotifier observes ALL the DownloadItems on a given
+// AllDownloadItemNotifier observes ALL the DownloadItems on a given
// DownloadManager.
// Clients should use GetManager() instead of storing their own pointer to the
This is Rietveld 408576698